
# Type: required


true means that the slot must be present in the loaded definition

URI: [meta:required](https://w3id.org/biolink/biolinkml/meta/required)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
